@@ -14,7 +14,7 @@ from honcho.procfile import Procfile
 class ProcfileWatcherTest(TestCase):
     def test_add_watcher(self):
         plugin = ProcfileWatcher("", "", 1)
-        plugin.client= Mock()
+        plugin.circus_client = Mock()
         name = "name"
         cmd = "cmd"
         options = json.dumps({
@@ -32,7 +32,7 @@ class ProcfileWatcherTest(TestCase):
             "start": True,
         }})
         plugin.add_watcher(name=name, cmd=cmd)
-        plugin.client.call.assert_called_with(options)
+        plugin.circus_client.call.assert_called_with(options)
 
     def test_remove_watcher(self):
         plugin = ProcfileWatcher("", "", 1)
